include <lad_link.scad>;
include <lad_rack&gear.scad>;
include <lad_slider&track.scad>;
include <lad_bridge.scad>;
include <lad_nema14.scad>;
include <lad_head.scad>;

layer_height = 20;

////////////////////////////////////////
// frame
////////////////////////////////////////
frame_x_components = 2;
frame_y_components = 2;
frame_x_offset = -15 + (1+frame_y_components)*ladder_length/2;
frame_y_offset = -15 + (1+frame_x_components)*ladder_length/2;

for(x = [-frame_x_components/2:frame_x_components/2]) {
	translate([x*track_length, frame_x_offset, layer_height]) track();
	translate([x*track_length, -frame_x_offset, layer_height]) track();
}

for(y = [-frame_y_components/2:frame_y_components/2]) {
	translate([frame_y_offset, y*ladder_length, 0]) rotate([0, 0, 90]) rack();
	translate([-frame_y_offset, y*ladder_length, 0]) rotate([0, 0, 90]) rack();
}

////////////////////////////////////////
// bridge over frame
////////////////////////////////////////
bridge_offset = 7*(teeth_hole_length+teeth_length);

translate([frame_y_offset, bridge_offset, 0]) rotate([0, 0, -90]) {
	bridge_on_rack();
	translate([0, 2*bridge_y_offset, 2*bridge_z_offset]) rotate([180, 0, 0]) bridge_on_rack();
}

translate([-frame_y_offset, bridge_offset, 0]) rotate([0, 0, 90]) {
	bridge_on_rack();
	translate([0, 2*bridge_y_offset, 2*bridge_z_offset]) rotate([180, 0, 0]) bridge_on_rack();
}

translate([frame_y_offset, -bridge_offset, 0]) rotate([0, 0, -90]) {
	bridge_on_rack();
	translate([0, 2*bridge_y_offset, 2*bridge_z_offset]) rotate([180, 0, 0]) bridge_on_rack();
}

translate([-frame_y_offset, -bridge_offset, 0]) rotate([0, 0, 90]) {
	bridge_on_rack();
	translate([0, 2*bridge_y_offset, 2*bridge_z_offset]) rotate([180, 0, 0]) bridge_on_rack();
}

translate([bridge_y_offset+ladder_width/2, 0, 2*bridge_z_offset]) rotate([0, 0, 90]) rack();
translate([-bridge_y_offset-ladder_width/2, 0, 2*bridge_z_offset]) rotate([0, 0, 90]) rack();

////////////////////////////////////////
// x - axis
////////////////////////////////////////
bed_x_offset = 150;

translate([bed_x_offset, 0, layer_height]) {
	for(x = [-frame_x_components/2:frame_x_components/2]) {
		translate([x*track_length,0,0]) rack();
		translate([-x*track_length,0,0]) rack();
	}	
}

translate([0, frame_y_offset, (track_height-slider_height)+layer_height]) slider_for_motor();
translate([0, -frame_y_offset, (track_height-slider_height)+layer_height]) slider_for_tracks();

////////////////////////////////////////
// y - axis
////////////////////////////////////////
bed_y_offset = 150;
rack_x_offset = slider_length/2-5-track_width-sft_width-ladder_width/2;

translate([0, 0, 2*layer_height])  {
	for(y = [-frame_y_components/2:frame_y_components/2]) {
		translate([slider_length/2-track_width/2-5, y*ladder_length, 0]) 
			rotate([0,0,90]) track();
		translate([-(slider_length/2-track_width/2-5), y*ladder_length, 0]) 
			rotate([0,0,90]) track();
	}
}

translate([-rack_x_offset, bed_y_offset, 2*layer_height]) {
	for(y = [-frame_y_components/2:frame_y_components/2]) {
		translate([0, y*ladder_length, 0]) rotate([0,0,90]) rack();
	}
}

////////////////////////////////////////
// z - axis
////////////////////////////////////////
bed_z_offset = 200;

translate([bridge_y_offset+ladder_height+22, 0, bed_z_offset]) rotate([0, 90, 0]) rack();
translate([bridge_y_offset+ladder_height+22, 0, bed_z_offset+ladder_length]) rotate([0, 90, 0]) rack();

translate([-(bridge_y_offset+ladder_height+22), 0, bed_z_offset]) rotate([0, 90, 0]) rack();
translate([-(bridge_y_offset+ladder_height+22), 0, bed_z_offset+ladder_length]) rotate([0, 90, 0]) rack();

////////////////////////////////////////
// motors, hot-end, gears and bed
////////////////////////////////////////

// x axis motor
translate([frame_x_offset, 37, 22+layer_height]) rotate(a=[90,0,0]) nema14();
translate([frame_x_offset, 0, 22+layer_height]) rotate(a=[90,0,180]) gear();

// y axis motor
translate([37-rack_x_offset, frame_y_offset, 22+2*layer_height]) 
	rotate(a=[0,90,180]) nema14();
translate([-rack_x_offset, frame_y_offset, 22+2*layer_height]) rotate(a=[0,90,0]) gear();

// z axis motors
translate([bridge_y_offset+ladder_width/2, 37, 22+2*bridge_z_offset+layer_height/2]) 
	rotate(a=[90,0,0]) nema14();
translate([bridge_y_offset+ladder_width/2, 0, 22+2*bridge_z_offset+layer_height/2]) 
	rotate(a=[90,0,180]) gear();

translate([-(bridge_y_offset+ladder_width/2), 37, 22+2*bridge_z_offset+layer_height/2]) 
	rotate(a=[90,0,0]) nema14();
translate([-(bridge_y_offset+ladder_width/2), 0, 22+2*bridge_z_offset+layer_height/2]) 
	rotate(a=[90,0,180]) gear();

// bed sliders and bed
translate([slider_length/2-track_width/2-5, 0, (track_height-slider_height)+2*layer_height]) 
	rotate([0,0,90])
		slider();
translate([-(slider_length/2-track_width/2-5), 0, (track_height-slider_height)+2*layer_height])
	rotate([0,0,90])
		slider();
translate([0, 0, 3*layer_height]) cube([200, 200, 10], center=true);

// hot end
translate([0, 0, bed_z_offset-ladder_length/2]) head();

